==> qtmultimedia-opensource-src_5.12.8.orig.tar.xz: qtmultimedia-everywhere-src-5.12.8/src/plugins/directshow/player/directshowmetadatacontrol.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef DIRECTSHOWMETADATACONTROL_H
#define DIRECTSHOWMETADATACONTROL_H

#include <dshow.h>

#include <qmetadatareadercontrol.h>

#include "directshowglobal.h"

#include <QtCore/qcoreevent.h>

QT_BEGIN_NAMESPACE

class DirectShowMetaDataControl : public QMetaDataReaderControl
{
    Q_OBJECT
public:
    DirectShowMetaDataControl(QObject *parent = 0);
    ~DirectShowMetaDataControl() override;

    bool isMetaDataAvailable() const override;

    QVariant metaData(const QString &key) const override;
    QStringList availableMetaData() const override;

    void reset();
    void updateMetadata(IFilterGraph2 *graph, IBaseFilter *source,
                        const QString &fileSrc = QString());

protected:
    void customEvent(QEvent *event) override;

private:
    void setMetadataAvailable(bool available);

    enum Event
    {
        MetaDataChanged = QEvent::User
    };

    QVariantMap m_metadata;
    bool m_available;
};

QT_END_NAMESPACE

#endif

==> qtmultimedia-opensource-src_5.15.3.orig.tar.xz: qtmultimedia-everywhere-src-5.15.3/src/plugins/directshow/player/directshowmetadatacontrol.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef DIRECTSHOWMETADATACONTROL_H
#define DIRECTSHOWMETADATACONTROL_H

#include <dshow.h>

#include <qmetadatareadercontrol.h>

#include "directshowglobal.h"

#include <QtCore/qcoreevent.h>

QT_BEGIN_NAMESPACE

class DirectShowMetaDataControl : public QMetaDataReaderControl
{
    Q_OBJECT
public:
    DirectShowMetaDataControl(QObject *parent = nullptr);
    ~DirectShowMetaDataControl() override;

    bool isMetaDataAvailable() const override;

    QVariant metaData(const QString &key) const override;
    QStringList availableMetaData() const override;

    void setMetadata(const QVariantMap &metadata);

    static void updateMetadata(const QString &fileSrc, QVariantMap &metadata);
    static void updateMetadata(IFilterGraph2 *graph, IBaseFilter *source, QVariantMap &metadata);

private:
    void setMetadataAvailable(bool available);

    enum Event
    {
        MetaDataChanged = QEvent::User
    };

    QVariantMap m_metadata;
    bool m_available = false;
};

QT_END_NAMESPACE

#endif
